def can_build(env, platform):
    return platform == "iphone"


def configure(env):
    pass
